@@ -1,5 +1,4 @@
-
-package POE::Session::Cascading;
+#$Header: /cvsroot/POE-Session-Cascading/lib/POE/Session/Cascading.pm,v 1.13 2002/05/21 01:54:48 matt Exp $
 
 # DOCUMENTATION #{{{
 
@@ -9,11 +8,11 @@ POE::Session::Cascading - Stack-like POE Sessions
 
 =head1 AUTHOR
 
-Matt Cashner (sungo@pobox.com)
+Matt Cashner (eek+cpan@eekeek.org)
 
 =head1 DATE
 
-$Date$
+$Date: 2002/05/21 01:54:48 $
 
 =head1 SYNOPSIS
 
@@ -94,46 +93,28 @@ to the state, including any data passed from the previous state..
 
 #}}}
 
+package POE::Session::Cascading;
 
 use warnings;
 use strict;
 
 use Carp;
 use POE::Kernel;
-use vars qw(%STACK %STACKINFO);
+use vars qw($VERSION %STACK %STACKINFO);
 
-our $VERSION = '2.01';
-
-
-=begin devel
-
-=head2 CSC_STOP
-
-=head2 CSC_OK
-
-Internal constants to provide flow control
-
-
-=cut
-
-sub CSC_STOP () { 0 }
-sub CSC_OK () { 1 }
-
-
-=head2 DEBUG
-
-Allow users to configure our debug prints. Useful for the test suite
-
-=end devel
-
-=cut
+$VERSION = (qw($Revision: 1.13 $))[1];
 
+# allow users to set the debug flag. also useful for the test suite
 BEGIN {
     unless(defined &POE::Session::Cascading::DEBUG) {
         *POE::Session::Cascading::DEBUG = sub { 0 } ;
     }
 }               
 
+# Constants
+sub CSC_STOP () { 0 }
+sub CSC_OK () { 1 }
+
 
 # sub new {{{
 
@@ -208,6 +189,7 @@ sub _invoke_state {
         
         print "Setting kernel alias to $self->{name}\n" if DEBUG;
         $POE::Kernel::poe_kernel->alias_set($self->{name});
+        $POE::Kernel::poe_kernel->delay('_ping',10);
         
     } elsif ($state eq '_stop') {
         # Shutting down. Delete the relevant stack.
@@ -221,6 +203,10 @@ sub _invoke_state {
         
         return $self->step(@{$etc});
         
+    } elsif ($state eq '_ping') {
+        # The ping state is used to keep the session alive.
+        $POE::Kernel::poe_kernel->delay('_ping',10);
+
     } else {
         # A normal event. Do we know this event? Does it belong to stack?
         if(defined $self->{info}->{$state}) {
@@ -238,15 +224,8 @@ sub _invoke_state {
 
 # sub step {{{
 
-=begin devel
-
-=head2 step
-
-Take a single step in the stack. 
-If appropriate, increment the counter and post the call to take the next step.
-
-=cut
-
+# Take a single step in the stack. 
+# If appropriate, increment the counter and post the call to take the next step.
 sub step {
     my $self = shift;
     my $itr = shift;
@@ -263,18 +242,6 @@ sub step {
 }
 # }}}
 
-=head2 ID
-
-For compatibility with POE's native sessions.
-
-=end devel
-
-=cut
-
-sub ID {
-  $POE::Kernel::poe_kernel->ID_session_to_id(shift);
-}
-
 =head2 stop
 
     $args{SESSION}->stop;
@@ -338,13 +305,6 @@ sub swap {
     return 1;
 }
 
-=begin devel
-
-=head2 DESTROY
-
-Destructor. Clear out the stack for the given session
-
-=cut
 
 sub DESTROY {
     my $self = shift; 
@@ -353,13 +313,8 @@ sub DESTROY {
     delete $STACKINFO{$self->{name}};
 }
 
-=head2 assert
-
-um, this is assert, like in C. 
-if the condition is false, yell.
-
-=cut
-
+# um, this is assert, like in C. 
+# if the condition is false, yell.
 sub assert ($;$) {
     unless($_[0]) {
         Carp::confess( _fail_msg($_[1]) );
@@ -376,9 +331,6 @@ sub _fail_msg {
     return $msg;
 }     
 
-1;
-__END__
-
 # MORE DOCS {{{
 
 =head1 BUGS AND KNOWN ISSUES
@@ -391,42 +343,34 @@ __END__
 
 =back
 
-=head1 AUTHOR
+=head1 LICENSE AND COPYRIGHT
 
-Matt Cashner (sungo@pobox.com)
+Copyright (c) 2002, Matt Cashner 
 
-=head1 LICENSE
+Permission is hereby granted, free of charge, to any person obtaining 
+a copy of this software and associated documentation files (the 
+"Software"), to deal in the Software without restriction, including 
+without limitation the rights to use, copy, modify, merge, publish, 
+distribute, sublicense, and/or sell copies of the Software, and to 
+permit persons to whom the Software is furnished to do so, subject 
+to the following conditions:
 
-Copyright (c) 2002, Matt Cashner. All rights reserved.
+The above copyright notice and this permission notice shall be included 
+in all copies or substantial portions of the Software.
 
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are
-met:
-
-=over 4
-
-=item * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.  
-
-=item * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
-
-=item * Neither the name of Matt Cashner nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
-
-=back
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
+EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
+OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
+WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
+ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
 #}}}
 
-# sungo // vim: ts=4 sw=4 et
+1;
